@@ -276,9 +276,9 @@ class Client(object):
         return (
             exc_info[0],
             id(exc_info[1]),
-            id(exc_info[2].tb_frame.f_code),
+            id(exc_info[2] and exc_info[2].tb_frame.f_code),
             id(exc_info[2]),
-            exc_info[2].tb_lasti,
+            exc_info[2] and exc_info[2].tb_lasti,
         )
 
     def skip_error_for_logging(self, exc_info):
